package de.oaa.xxx.gruppe.repository;

import de.oaa.xxx.gruppe.entity.UmfrageStimmeEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

public interface UmfrageStimmeRepository extends JpaRepository<UmfrageStimmeEntity, UUID> {

    List<UmfrageStimmeEntity> findByBeitragIdAndUserId(UUID beitragId, UUID userId);

    Optional<UmfrageStimmeEntity> findByOptionIdAndUserId(UUID optionId, UUID userId);

    long countByOptionId(UUID optionId);

    @Transactional
    void deleteByBeitragId(UUID beitragId);
}
